def consultar(path):
    cpf = input("Insert cpf to search")
    i = 0
    with open(path, "r") as arq:
        lines = arq.readlines()
        for line in lines:
            i += 1
            if cpf in line:
                for j in range(i, i + 2):
                    print(lines[j])



from setuptools import setup

with open("README.md", "r") as fh:
    readme = fh.read()

setup(name='CRUD - INFO',
      version='0.0.1',
      url='https://github.com/Fabreba/Info_CRUD',
      license='MIT License',
      author='Fabricio Silva',
      long_description=readme,
      long_description_content_type="text/markdown",
      author_email='fabricioj49@gmail.com',
      keywords='Pacote',
      description='Pacote que recebe informacoes e printa ao usuario',
      packages=['CRUD_ID', 'CRUD_ID.Consulta', 'CRUD_ID.Interecao', 'CRUD_ID.Armazenamento'],
      install_requires=['os'], )



import CRUD_ID.Armazenamento.Armazenar


def insert(path):
    name = input("Insert your name")
    cpf = input("Insert your cpf")
    address = input("Insert your address")
    return CRUD_ID.Armazenamento.Armazenar.store(name, cpf, address, path)
